@@ -478,7 +478,8 @@ class OEMHandler(generic.OEMHandler):
         elif self.has_imm:
             return self.immhandler.get_hw_descriptions()
         elif self.is_fpc:
-            return self.smmhandler.get_inventory_descriptions(self.is_fpc)
+            return self.smmhandler.get_inventory_descriptions(self.ipmicmd,
+                                                              self.is_fpc)
         return ()
 
     def get_oem_inventory(self):
@@ -1341,6 +1342,8 @@ class OEMHandler(generic.OEMHandler):
                 else:
                     zerofru['UUID'] = util.decode_wireformat_uuid(
                         guiddata['data'])
+        if self.is_fpc:
+            self.smmhandler.augment_zerofru(zerofru, self._fpc_variant)
         return self.process_fru(zerofru)
 
     def get_ami_sensor_reading(self, sensorname):
