@@ -642,13 +642,14 @@ class OEMHandler(generic.OEMHandler):
         parms = {'raidlink_AddNewVolWithNaAsync': arglist}
         rsp = self.wc.grab_json_response(url, parms)
         if rsp['return'] == 14:  # newer firmware
-            arglist = '{0},{1},{2},{3},{4},{5},{6},'.format(
-                cnum, params['raidlevel'], params['spans'],
-                params['perspan'], 0, params['drives'], params['hotspares'])
-            arglist += ''.join(vols)
-            parms = {'raidlink_AddNewVolWithNaAsync': arglist}
-            rsp = self.wc.grab_json_response(url, parms)
-            if not rsp: # Purley
+            if 'supported_cpwb' in props: # Whitley
+                arglist = '{0},{1},{2},{3},{4},{5},{6},'.format(
+                    cnum, params['raidlevel'], params['spans'],
+                    params['perspan'], 0, params['drives'], params['hotspares'])
+                arglist += ''.join(vols)
+                parms = {'raidlink_AddNewVolWithNaAsync': arglist}
+                rsp = self.wc.grab_json_response(url, parms)
+            else: # Purley
                 if cid[2] == 2:
                     cnum = cid[1]
                 arglist = '{0},{1},{2},{3},{4},{5},'.format(
